pub fn estimate_key_from_chords_with(
profile: KeyProfile,
chords: &[Chord],
) -> Result<Vec<KeyEstimate>>Expand description
Estimates likely keys from chords using the given weights.
pub fn estimate_key_from_chords_with(
profile: KeyProfile,
chords: &[Chord],
) -> Result<Vec<KeyEstimate>>Estimates likely keys from chords using the given weights.