pub fn estimate_key_from_pitches_with(
profile: KeyProfile,
pitches: &[Pitch],
) -> Result<Vec<KeyEstimate>>Expand description
Estimates likely keys from pitches using the given weights.
pub fn estimate_key_from_pitches_with(
profile: KeyProfile,
pitches: &[Pitch],
) -> Result<Vec<KeyEstimate>>Estimates likely keys from pitches using the given weights.