format_vector_string

Function format_vector_string 

pub fn format_vector_string(values: &[u8]) -> String
Writes a list of pitch classes the way music21’s Chord.formatVectorString does, with ten and eleven as A and B: [0, 11] is <0B>.