pub enum IntervalDirection {
Descending = -1,
Oblique = 0,
Ascending = 1,
}Expand description
Direction of a directed interval.
Variants
Descending = -1
The end pitch is lower than the start pitch.
Oblique = 0
The interval is an oblique unison.
Ascending = 1
The end pitch is higher than the start pitch.
Implementations