convert_semitone_to_specifier_generic_microtone

Function convert_semitone_to_specifier_generic_microtone 

pub fn convert_semitone_to_specifier_generic_microtone(
    count: FloatType,
) -> (Specifier, IntegerType, FloatType)
Like convert_semitone_to_specifier_generic for a fractional semitone count, returning the leftover in cents as well: music21’s convertSemitoneToSpecifierGenericMicrotone, so 2.5 is a major second and fifty cents, and -2.5 a descending minor third and fifty.