Notehead

Enum Notehead 

pub enum Notehead {
Show 28 variants ArrowDown, ArrowUp, BackSlashed, CircleDot, CircleX, Circled, Cluster, Cross, Diamond, Do, Fa, FaUp, InvertedTriangle, La, LeftTriangle, Mi, NoneShape, Normal, Other, Re, Rectangle, Slash, Slashed, So, Square, Ti, Triangle, X,
}
The shape drawn for a note head: music21’s noteheadTypeNames.

Variants



ArrowDown

arrow down



ArrowUp

arrow up



BackSlashed

back slashed



CircleDot

circle dot



CircleX

circle-x



Circled

circled



Cluster

cluster



Cross

cross



Diamond

diamond, which is how a string harmonic is written.



Do

do



Fa

fa



FaUp

fa up



InvertedTriangle

inverted triangle



La

la



LeftTriangle

left triangle



Mi

mi



NoneShape

none



Normal

normal, the default.



Other

other



Re

re



Rectangle

rectangle



Slash

slash



Slashed

slashed



So

so



Square

square



Ti

ti



Triangle

triangle



X

x

Implementations

Source

impl Notehead

pub const ALL: [Notehead; 28]

Every notehead shape, in music21’s order.

pub fn as_str(self) -> &'static str

music21’s name for the shape.

pub fn from_name(name: &str) -> Result<Self>

Reads music21’s name for the shape.