IntoNote

Trait IntoNote 

pub trait IntoNote {
    const FROM_INTEGER_PITCH: bool = false;

    // Required method
    fn try_into_note(self) -> Result<Note>;
}
Converts a single note-like value into a Note.

This is useful when constructing vectors or other collections that are later passed to APIs such as Chord::new.

Provided Associated Constants

const FROM_INTEGER_PITCH: bool = false

Whether this value came from an integer pitch class or MIDI-like number.

Required Methods

fn try_into_note(self) -> Result<Note>

Converts the value into a note.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementations on Foreign Types

Source

impl IntoNote for &String

Source

impl IntoNote for &str

Source

impl IntoNote for String

Implementors