convert_pitch_class_to_str

Function convert_pitch_class_to_str 

pub fn convert_pitch_class_to_str(pc: IntegerType) -> String
music21’s convertPitchClassToStr: an integer pitch class as one character, A for ten and B for eleven, reduced modulo twelve first.