pub struct Microtone { /* private fields */ }Expand description
A microtonal pitch adjustment measured in cents, optionally shifted by a
harmonic like Python music21’s music21.pitch.Microtone.
Implementations
Sourceimpl Microtone
impl Microtone
Sourcepub fn new(specifier: impl Into<MicrotoneSpecifier>) -> Result<Self>
pub fn new(specifier: impl Into<MicrotoneSpecifier>) -> Result<Self>
Creates a microtone with no harmonic shift.
Sourcepub fn with_harmonic_shift(
specifier: impl Into<MicrotoneSpecifier>,
harmonic_shift: IntegerType,
) -> Result<Self>
pub fn with_harmonic_shift( specifier: impl Into<MicrotoneSpecifier>, harmonic_shift: IntegerType, ) -> Result<Self>
Creates a microtone with an explicit harmonic shift.
Sourcepub fn alter(&self) -> FloatType
pub fn alter(&self) -> FloatType
Returns the microtone in accidental alter units, where 100 cents is 1.0.
Sourcepub fn cents(&self) -> FloatType
pub fn cents(&self) -> FloatType
Returns the total cent displacement, including harmonic shift.
Sourcepub fn cent_shift(&self) -> FloatType
pub fn cent_shift(&self) -> FloatType
Returns the direct cent shift before harmonic adjustment.
Sourcepub fn set_cent_shift(&mut self, cents: FloatType)
pub fn set_cent_shift(&mut self, cents: FloatType)
Sets the direct cent shift before harmonic adjustment.
Sourcepub fn harmonic_shift(&self) -> IntegerType
pub fn harmonic_shift(&self) -> IntegerType
Returns the harmonic shift.
Sourcepub fn set_harmonic_shift(&mut self, harmonic_shift: IntegerType)
pub fn set_harmonic_shift(&mut self, harmonic_shift: IntegerType)
Sets the harmonic shift.