pub struct PitchClass { /* private fields */ }Expand description
A normalized pitch-class value.
Pitch classes wrap into the range 0 <= pc < 12. Integer pitch classes
display using music21’s hexadecimal-style spellings: A for 10 and B for
11.
Implementations
Sourceimpl PitchClass
impl PitchClass
Sourcepub fn new(specifier: impl Into<PitchClassSpecifier>) -> Result<Self>
pub fn new(specifier: impl Into<PitchClassSpecifier>) -> Result<Self>
Creates a normalized pitch class from a number, string, or existing pitch class.
Sourcepub fn integer(&self) -> Option<IntegerType>
pub fn integer(&self) -> Option<IntegerType>
Returns the integer pitch class if this value is not microtonal.