pub enum TransformationConvention {
ZeroCentered,
OriginalCentered,
}Expand description
What the index of a transformation refers to.
Variants
ZeroCentered
P(n) and I(n) start on pitch class n; R(n) and RI(n) end on
it. This is the common convention and music21’s default.
OriginalCentered
T(n) transposes the original row up n semitones, and I(n),
R(n) and RI(n) transform the row in place and then transpose the
result by n.
Implementations