row_to_matrix

Function row_to_matrix 

pub fn row_to_matrix(pitch_classes: &[IntegerType]) -> String
music21’s rowToMatrix: the matrix of a pitch-class list as text, with the pitch classes written in decimal rather than as A and B.