convert_tempo_by_referent

Function convert_tempo_by_referent 

pub fn convert_tempo_by_referent(
    number: FloatType,
    source_quarter_length: FloatType,
    destination_quarter_length: FloatType,
) -> FloatType
Converts a tempo counted in one note value into the same tempo counted in another, both given in quarter lengths.

Sixty half notes a minute is a hundred and twenty quarters.