default_number_for_text

Function default_number_for_text 

pub fn default_number_for_text(text: &str) -> Option<FloatType>
Returns the beats per minute music21 pairs with a tempo word, matching the whole text case-insensitively first and any single word of it second.