get_cents_at

Function get_cents_at 

pub fn get_cents_at(
    tuning_system: TuningSystem,
    index: FloatType,
    size: Option<UnsignedIntegerType>,
) -> FloatType
Returns cents offset from equal temperament for a fractional degree index.

The optional size overrides the octave size of the equal-temperament comparison.