Fraction

Struct Fraction 

pub struct Fraction {
    pub numerator: UnsignedIntegerType,
    pub denominator: UnsignedIntegerType,
    pub base: UnsignedIntegerType,
}
A ratio-like value used by tuning tables.

Fields

numerator: UnsignedIntegerType

Numerator for a rational ratio, or exponent numerator when base is set.

denominator: UnsignedIntegerType

Denominator for a rational ratio, or exponent denominator when base is set.

base: UnsignedIntegerType

Exponential base. A value of 0 means use numerator / denominator.

Implementations

Source

impl Fraction

pub const fn new( numerator: UnsignedIntegerType, denominator: UnsignedIntegerType, ) -> Self

Creates a rational fraction.

pub const fn new_with_base( numerator: UnsignedIntegerType, denominator: UnsignedIntegerType, base: UnsignedIntegerType, ) -> Self

Creates a fraction with an optional exponential base.

pub const fn numerator(&self) -> UnsignedIntegerType

Returns the numerator.

pub const fn denominator(&self) -> UnsignedIntegerType

Returns the denominator.

pub const fn base(&self) -> UnsignedIntegerType

Returns the exponential base, or 0 for rational ratios.

pub fn ratio(self) -> FloatType

Converts this value into a floating-point ratio.

pub fn label(self) -> String

Returns a compact music-friendly display label.

pub fn with_octaves(self, octaves: UnsignedIntegerType) -> Self

Returns this fraction shifted upward by octaves.