pub struct KeySignature { /* private fields */ }Expand description
A key signature represented by the number of sharps.
Flats are represented as negative sharps, so B-flat major has -2.
Implementations
Sourceimpl KeySignature
impl KeySignature
Sourcepub fn new(sharps: IntegerType) -> Self
pub fn new(sharps: IntegerType) -> Self
Creates a key signature from a sharp count.
Sourcepub fn sharps(&self) -> IntegerType
pub fn sharps(&self) -> IntegerType
Returns the number of sharps, with flats as negative values.