pub fn snapped_fraction(value: FloatType) -> FloatTypeExpand description
A fractional beat read as the fraction it suggests: music21’s
addFloatPrecision, which snaps a third, two thirds, a sixth or five
sixths written as decimals onto the fraction itself.
It is what makes the offset of beat 2.33 the same as the offset of beat two and a third.