pub struct Note { /* private fields */ }Expand description
A pitched note.
Implementations
Sourceimpl Note
impl Note
Sourcepub fn from_name(name: impl Into<String>) -> Result<Self>
pub fn from_name(name: impl Into<String>) -> Result<Self>
Builds a note from a pitch name such as "C#4" or "E-".
Sourcepub fn from_pitch(pitch: Pitch) -> Result<Self>
pub fn from_pitch(pitch: Pitch) -> Result<Self>
Builds a note from an existing Pitch.
Sourcepub fn pitch_name(&self) -> String
pub fn pitch_name(&self) -> String
Returns the pitch name without an octave, such as "C#" or "E-".
Sourcepub fn pitch_name_with_octave(&self) -> String
pub fn pitch_name_with_octave(&self) -> String
Returns the pitch name with an octave when one is set.
Sourcepub fn duration(&self) -> Option<&Duration>
pub fn duration(&self) -> Option<&Duration>
Returns the note duration when one has been assigned.
Sourcepub fn set_duration(&mut self, duration: Duration)
pub fn set_duration(&mut self, duration: Duration)
Assigns a duration to the note.
Sourcepub fn with_duration(self, duration: Duration) -> Self
pub fn with_duration(self, duration: Duration) -> Self
Returns a copy of this note with the supplied duration.