pub fn convert_pitch_class_to_str(pc: IntegerType) -> StringExpand description
music21’s convertPitchClassToStr: an integer pitch class as one
character, A for ten and B for eleven, reduced modulo twelve first.
pub fn convert_pitch_class_to_str(pc: IntegerType) -> Stringmusic21’s convertPitchClassToStr: an integer pitch class as one
character, A for ten and B for eleven, reduced modulo twelve first.