Pitch

Struct Pitch 

pub struct Pitch { /* private fields */ }
A musical pitch with spelling, octave, accidental and optional microtone.

Implementations

Source

impl Pitch

pub fn from_options(options: PitchOptions) -> Result<Self>

Builds a pitch from PitchOptions.

pub fn builder() -> PitchOptions

Creates a PitchOptions builder.

pub fn from_name(name: impl Into<String>) -> Result<Self>

Builds a pitch from a name such as "C#4" or "E-".

pub fn from_number(number: FloatType) -> Result<Self>

Builds a pitch from a pitch-space number.

pub fn from_step(step: char) -> Result<Self>

Builds a pitch from a diatonic step.

pub fn from_name_and_octave( name: impl Into<String>, octave: IntegerType, ) -> Result<Self>

Builds a pitch from a pitch name and explicit octave.

pub fn from_pitch_class( pitch_class: impl Into<PitchClassSpecifier>, ) -> Result<Self>

Builds a pitch from a pitch class.

pub fn from_midi(midi: IntegerType) -> Result<Self>

Builds a pitch from a MIDI note number.

pub fn from_pitch_space(ps: FloatType) -> Result<Self>

Builds a pitch from a pitch-space value.

pub fn name_with_octave(&self) -> String

Returns the pitch name with the octave suffix when one is set.

pub fn name(&self) -> String

Returns the pitch name without octave, such as "F#" or "B-".

pub fn alter(&self) -> FloatType

Returns the total semitone alteration from the natural step.

pub fn accidental(&self) -> &Accidental

Returns this pitch’s accidental object.

Unlike Python music21, this crate stores an explicit natural accidental for natural pitches.

pub fn microtone(&self) -> Option<&Microtone>

Returns this pitch’s microtone adjustment, when present.

pub fn pitch_class(&self) -> PitchClass

Returns this pitch’s normalized pitch class.

pub fn ps(&self) -> FloatType

Returns the pitch-space value for this pitch.

pub fn pitch_space(&self) -> FloatType

Returns the pitch-space value for this pitch.

pub fn midi(&self) -> IntegerType

Returns the nearest MIDI note number for this pitch.

pub fn frequency_hz(&self) -> FloatType

Returns this pitch’s twelve-tone equal-temperament frequency in hertz.

pub fn frequency_hz_in(&self, tuning_system: TuningSystem) -> FloatType

Returns this pitch’s frequency in hertz for a supported tuning system.

The pitch-space value is used as the tuning-system degree index, so this is most musically meaningful for twelve-tone systems.

pub fn octave(&self) -> Octave

Returns the stored octave.

Returns None when the pitch was created without an explicit octave, such as Pitch::from_name("C"). In calculations, octave-less pitches use the library default octave.