pub fn row_to_matrix(pitch_classes: &[IntegerType]) -> StringExpand description
music21’s rowToMatrix: the matrix of a pitch-class list as text, with
the pitch classes written in decimal rather than as A and B.
pub fn row_to_matrix(pitch_classes: &[IntegerType]) -> Stringmusic21’s rowToMatrix: the matrix of a pitch-class list as text, with
the pitch classes written in decimal rather than as A and B.