pub enum StreamElement {
Note(Note),
Chord(Chord),
Rest(Rest),
}Expand description
A musical object that can live on a timeline.
Variants
Note(Note)
A single pitched note.
Chord(Chord)
A chord containing one or more notes.
Rest(Rest)
A silent rest.
Implementations
Sourceimpl StreamElement
impl StreamElement
Sourcepub fn quarter_length(&self) -> FloatType
pub fn quarter_length(&self) -> FloatType
Returns the duration in quarter lengths, defaulting to 1.0.