pub struct Stream { /* private fields */ }Expand description
A small ordered stream of notes, chords, and rests.
Implementations
Sourceimpl Stream
impl Stream
Sourcepub fn from_events(events: impl IntoIterator<Item = StreamEvent>) -> Self
pub fn from_events(events: impl IntoIterator<Item = StreamEvent>) -> Self
Creates a stream from events, sorted by offset.
Sourcepub fn insert(&mut self, offset: FloatType, element: impl Into<StreamElement>)
pub fn insert(&mut self, offset: FloatType, element: impl Into<StreamElement>)
Inserts an element at a quarter-length offset.
Sourcepub fn push(&mut self, element: impl Into<StreamElement>)
pub fn push(&mut self, element: impl Into<StreamElement>)
Appends an element after the current end of the stream.
Sourcepub fn events(&self) -> &[StreamEvent]
pub fn events(&self) -> &[StreamEvent]
Returns immutable events in offset order.
Sourcepub fn iter(&self) -> impl Iterator<Item = &StreamEvent>
pub fn iter(&self) -> impl Iterator<Item = &StreamEvent>
Iterates over events in offset order.
Sourcepub fn end_offset(&self) -> FloatType
pub fn end_offset(&self) -> FloatType
Returns the maximum event end offset.