TuningSystem

Enum TuningSystem 

pub enum TuningSystem {
Show 17 variants EqualTemperament { octave_size: UnsignedIntegerType, }, RecursiveEqualTemperament { octave_size: UnsignedIntegerType, }, WholeTone, QuarterTone, JustIntonation, JustIntonation24, PythagoreanTuning, FiveLimit, ElevenLimit, FortyThreeTone, StepMethod, Javanese, Thai, Indian, IndianAlt, Indian22, IndianFull,
}
Supported tuning systems and ratio tables.

Variants



EqualTemperament

Equal temperament with a configurable octave size.

Fields

octave_size: UnsignedIntegerType

Number of equal divisions in each octave.



RecursiveEqualTemperament

Recursive equal temperament with a configurable octave size.

Fields

octave_size: UnsignedIntegerType

Number of equal divisions in each octave.



WholeTone

Six-tone equal temperament.



QuarterTone

Twenty-four-tone equal temperament.



JustIntonation

Twelve-tone just intonation table.



JustIntonation24

Twenty-four-tone just intonation table.



PythagoreanTuning

Twelve-tone Pythagorean tuning table.



FiveLimit

Twelve-tone five-limit table.



ElevenLimit

Twenty-nine-tone eleven-limit table.



FortyThreeTone

Forty-three-tone ratio table.



StepMethod

Twelve-tone step-method equal temperament.



Javanese

Five-tone Javanese equal-temperament approximation.



Thai

Seven-tone Thai equal-temperament approximation.



Indian

Seven-tone Indian scale table.



IndianAlt

Alternate seven-tone Indian scale table.



Indian22

Twenty-two-tone Indian scale table.



IndianFull

Full twenty-two-tone Indian scale table.

Implementations

Source

impl TuningSystem

pub fn id(self) -> &'static str

Returns the canonical identifier used by FromStr.

pub fn display_name(self) -> &'static str

Returns a compact display name for this tuning system.

pub fn description(self) -> &'static str

Returns a short description of this tuning system.

pub fn ratio(self, index: usize) -> FloatType

Returns the frequency ratio for a degree index.

pub fn fraction(self, index: usize) -> Fraction

Returns the table fraction for a degree index.

pub fn label(self, index: UnsignedIntegerType) -> String

Returns a display label for a degree index.

pub fn octave(self, index: UnsignedIntegerType) -> UnsignedIntegerType

Returns the octave number containing a degree index.

pub fn frequency(self, index: UnsignedIntegerType) -> FloatType

Returns the frequency in hertz for a degree index.

pub fn frequency_at(self, index: FloatType) -> FloatType

Returns the frequency in hertz for a fractional degree index.

pub fn cents(self, index: UnsignedIntegerType) -> FloatType

Returns cents offset from equal temperament for a degree index.

pub fn cents_at(self, index: FloatType) -> FloatType

Returns cents offset from equal temperament for a fractional degree index.

pub fn octave_size(self) -> UnsignedIntegerType

Returns the number of degrees in one octave for this tuning system.