pub struct Fraction {
pub numerator: UnsignedIntegerType,
pub denominator: UnsignedIntegerType,
pub base: UnsignedIntegerType,
}Expand description
A ratio-like value used by tuning tables.
Fields
numerator: UnsignedIntegerTypeNumerator for a rational ratio, or exponent numerator when base is set.
denominator: UnsignedIntegerTypeDenominator for a rational ratio, or exponent denominator when base is set.
base: UnsignedIntegerTypeExponential base. A value of 0 means use numerator / denominator.
Implementations
Sourceimpl Fraction
impl Fraction
Sourcepub const fn new(
numerator: UnsignedIntegerType,
denominator: UnsignedIntegerType,
) -> Self
pub const fn new( numerator: UnsignedIntegerType, denominator: UnsignedIntegerType, ) -> Self
Creates a rational fraction.
Sourcepub const fn new_with_base(
numerator: UnsignedIntegerType,
denominator: UnsignedIntegerType,
base: UnsignedIntegerType,
) -> Self
pub const fn new_with_base( numerator: UnsignedIntegerType, denominator: UnsignedIntegerType, base: UnsignedIntegerType, ) -> Self
Creates a fraction with an optional exponential base.
Sourcepub const fn numerator(&self) -> UnsignedIntegerType
pub const fn numerator(&self) -> UnsignedIntegerType
Returns the numerator.
Sourcepub const fn denominator(&self) -> UnsignedIntegerType
pub const fn denominator(&self) -> UnsignedIntegerType
Returns the denominator.
Sourcepub const fn base(&self) -> UnsignedIntegerType
pub const fn base(&self) -> UnsignedIntegerType
Returns the exponential base, or 0 for rational ratios.
Sourcepub fn with_octaves(self, octaves: UnsignedIntegerType) -> Self
pub fn with_octaves(self, octaves: UnsignedIntegerType) -> Self
Returns this fraction shifted upward by octaves.